@@ -87,29 +87,35 @@ Railway::Train - a running engine
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 ATTRIBUTES
 
 =head2 manager
+
 A L<Railway::Builder> instance
 
 =head2 index
+
 An index
 
 =head2 way
+
 A L<Railway::Way> instance
 
 =head2 cargo
-A cargo for the train
+
+Cargo for a train
 
 =head2 done
+
 A code that will be passed after train reaches the end of the L</"way">
 
 =head1 METHODS
 
 =head2 power
-A switcher for train. Accepts C<true> or C<false>.
+
+A switcher for a train. Accepts C<true> or C<false>.
 Throws an exception if the same value provided twice 
 
   $train->power(1)->power(0)
@@ -118,9 +124,11 @@ Throws an exception if the same value provided twice
   $train->power(1)->power(1);
 
 =head2 run
+
 Run an engine
 
 =head2 prepare
+
 Prepare an engine. Starts L</"index"> to 0, L</"power"> to 1, check stations;
 If something is wrong, an exception will be thrown
 
@@ -132,19 +140,24 @@ If something is wrong, an exception will be thrown
 Prepare and run a train. You can provide a callback for L</"done">
 
 =head2 can_run
+
 Check if a way has a stations more than current L</"index">
 
 =head2 finish
+
 This method invokes a L</"done"> callback. Will be called just after a train
 will have reached the end of the way
 
 =head2 handle_station
+
 Safely executes a code
 
 =head2 depart
+
 Increase index by one. Raises an error if index isn't defined
 
 =head2 get_station
+
 Get current station
 
 =head1 Description
